/********************************************************************************
** Form generated from reading UI file 'codegenstatuspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEGENSTATUSPAGE_H
#define UI_CODEGENSTATUSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CodeGenStatusPage
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *ui_tabWidget;
    QWidget *ui_statusTab;
    QVBoxLayout *verticalLayout;
    QTableWidget *ui_tableWidgetStatus;
    QWidget *ui_loggerTab;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *ui_textEditLogger;
    QGridLayout *gridLayout_4;
    QPushButton *ui_pushButtonClear;
    QPushButton *ui_pushButtonExport;
    QHBoxLayout *hboxLayout;
    QPushButton *ui_pushButtonGenerate;

    void setupUi(QWidget *CodeGenStatusPage)
    {
        if (CodeGenStatusPage->objectName().isEmpty())
            CodeGenStatusPage->setObjectName("CodeGenStatusPage");
        CodeGenStatusPage->resize(500, 530);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CodeGenStatusPage->sizePolicy().hasHeightForWidth());
        CodeGenStatusPage->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(CodeGenStatusPage);
        vboxLayout->setObjectName("vboxLayout");
        ui_tabWidget = new QTabWidget(CodeGenStatusPage);
        ui_tabWidget->setObjectName("ui_tabWidget");
        ui_statusTab = new QWidget();
        ui_statusTab->setObjectName("ui_statusTab");
        verticalLayout = new QVBoxLayout(ui_statusTab);
        verticalLayout->setObjectName("verticalLayout");
        ui_tableWidgetStatus = new QTableWidget(ui_statusTab);
        if (ui_tableWidgetStatus->columnCount() < 3)
            ui_tableWidgetStatus->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        ui_tableWidgetStatus->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        ui_tableWidgetStatus->setObjectName("ui_tableWidgetStatus");
        ui_tableWidgetStatus->setAlternatingRowColors(true);
        ui_tableWidgetStatus->setColumnCount(3);

        verticalLayout->addWidget(ui_tableWidgetStatus);

        ui_tabWidget->addTab(ui_statusTab, QString());
        ui_loggerTab = new QWidget();
        ui_loggerTab->setObjectName("ui_loggerTab");
        verticalLayout_3 = new QVBoxLayout(ui_loggerTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        ui_textEditLogger = new QTextEdit(ui_loggerTab);
        ui_textEditLogger->setObjectName("ui_textEditLogger");

        verticalLayout_2->addWidget(ui_textEditLogger);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        ui_pushButtonClear = new QPushButton(ui_loggerTab);
        ui_pushButtonClear->setObjectName("ui_pushButtonClear");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ui_pushButtonClear->sizePolicy().hasHeightForWidth());
        ui_pushButtonClear->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(ui_pushButtonClear, 0, 0, 1, 1);

        ui_pushButtonExport = new QPushButton(ui_loggerTab);
        ui_pushButtonExport->setObjectName("ui_pushButtonExport");
        sizePolicy1.setHeightForWidth(ui_pushButtonExport->sizePolicy().hasHeightForWidth());
        ui_pushButtonExport->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(ui_pushButtonExport, 0, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);


        verticalLayout_3->addLayout(verticalLayout_2);

        ui_tabWidget->addTab(ui_loggerTab, QString());

        vboxLayout->addWidget(ui_tabWidget);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        ui_pushButtonGenerate = new QPushButton(CodeGenStatusPage);
        ui_pushButtonGenerate->setObjectName("ui_pushButtonGenerate");
        sizePolicy1.setHeightForWidth(ui_pushButtonGenerate->sizePolicy().hasHeightForWidth());
        ui_pushButtonGenerate->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(ui_pushButtonGenerate);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(CodeGenStatusPage);

        ui_tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CodeGenStatusPage);
    } // setupUi

    void retranslateUi(QWidget *CodeGenStatusPage)
    {
        QTableWidgetItem *___qtablewidgetitem = ui_tableWidgetStatus->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Class", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = ui_tableWidgetStatus->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Status", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_statusTab), tr2i18n("Status", nullptr));
        ui_pushButtonClear->setText(tr2i18n("Clear", nullptr));
        ui_pushButtonExport->setText(tr2i18n("Export...", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_loggerTab), tr2i18n("Logger", nullptr));
        ui_pushButtonGenerate->setText(tr2i18n("Generate", nullptr));
        (void)CodeGenStatusPage;
    } // retranslateUi

};

namespace Ui {
    class CodeGenStatusPage: public Ui_CodeGenStatusPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEGENSTATUSPAGE_H

